==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/WitherSpider.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1267;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1628;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.ai.goal.*;

public class WitherSpider extends class_1628 {
	public WitherSpider(class_1299<WitherSpider> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5959() {
		field_6201.method_6277(0, new class_1347(this));
		field_6201.method_6277(1, new class_1366(this, 1.0D, false));
		field_6201.method_6277(2, new class_1394(this, 0.8D));
		field_6201.method_6277(3, new class_1361(this, class_1657.class, 8.0F));
		field_6201.method_6277(4, new class_1376(this));
		field_6185.method_6277(1, new class_1399(this));
		field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
	}

	public static class_5132.class_5133 method_26923() {
		return class_1308.method_26828()
				.method_26868(class_5134.field_23719, 0.24F)
				.method_26868(class_5134.field_23717, 16.0D)
				.method_26868(class_5134.field_23716, 15.0D)
				.method_26868(class_5134.field_23721, 2.0D)
				.method_26868(class_5134.field_23723, 2.0D)
				.method_26868(class_5134.field_23722, 1.0D);
	}

	protected class_3414 method_5994() {
		return class_3417.field_15214;
	}
	protected class_3414 method_6002() {
		return class_3417.field_15122;
	}
	protected class_3414 method_6011(class_1282 source) {
		return class_3417.field_15027;
	}

	public static boolean canSpawn(class_1299<WitherSpider> entity, class_1936 level, class_3730 spawnType, class_2338 pos, class_5819 random) {
		return class_1314.method_20636(entity, level, spawnType, pos, random) && level instanceof class_1937 level1 && level1.method_8407() != class_1267.field_5801;
	}

	public boolean method_6121(class_1297 entity) {
		if (!super.method_6121(entity)) return false;
		if (entity instanceof class_1309) {
			((class_1309) entity).method_37222(new class_1293(class_1294.field_5920, 200), this);
		}
		return true;
	}

	public boolean method_6049(class_1293 instance) {
		return instance.method_5579() != class_1294.field_5920 && super.method_6049(instance);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/world/entity/WitherSpider.java <==
package net.invictusslayer.slayersbeasts.world.entity;

import net.minecraft.class_1267;
import net.minecraft.class_1282;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1347;
import net.minecraft.class_1361;
import net.minecraft.class_1366;
import net.minecraft.class_1376;
import net.minecraft.class_1394;
import net.minecraft.class_1399;
import net.minecraft.class_1400;
import net.minecraft.class_1628;
import net.minecraft.class_1657;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_3218;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3730;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_5819;
import net.minecraft.world.entity.*;
import net.minecraft.world.entity.ai.goal.*;

public class WitherSpider extends class_1628 {
	public WitherSpider(class_1299<WitherSpider> type, class_1937 level) {
		super(type, level);
	}

	protected void method_5959() {
		field_6201.method_6277(0, new class_1347(this));
		field_6201.method_6277(1, new class_1366(this, 1.0D, false));
		field_6201.method_6277(2, new class_1394(this, 0.8D));
		field_6201.method_6277(3, new class_1361(this, class_1657.class, 8.0F));
		field_6201.method_6277(4, new class_1376(this));
		field_6185.method_6277(1, new class_1399(this));
		field_6185.method_6277(2, new class_1400<>(this, class_1657.class, true));
	}

	public static class_5132.class_5133 method_26923() {
		return class_1308.method_26828()
				.method_26868(class_5134.field_23719, 0.24F)
				.method_26868(class_5134.field_23717, 16.0D)
				.method_26868(class_5134.field_23716, 15.0D)
				.method_26868(class_5134.field_23721, 2.0D)
				.method_26868(class_5134.field_23723, 2.0D)
				.method_26868(class_5134.field_23722, 1.0D);
	}

	protected class_3414 method_5994() {
		return class_3417.field_15214;
	}
	protected class_3414 method_6002() {
		return class_3417.field_15122;
	}
	protected class_3414 method_6011(class_1282 source) {
		return class_3417.field_15027;
	}

	public static boolean canSpawn(class_1299<WitherSpider> entity, class_1936 level, class_3730 reason, class_2338 pos, class_5819 random) {
		return class_1314.method_20636(entity, level, reason, pos, random) && level instanceof class_1937 level1 && level1.method_8407() != class_1267.field_5801;
	}

	public boolean method_6121(class_3218 level, class_1297 entity) {
		if (!super.method_6121(level, entity)) return false;
		if (entity instanceof class_1309) {
			((class_1309) entity).method_37222(new class_1293(class_1294.field_5920, 200), this);
		}
		return true;
	}

	public boolean method_6049(class_1293 instance) {
		return instance.method_5579() != class_1294.field_5920 && super.method_6049(instance);
	}
}
